@@ -3,7 +3,7 @@
 ;; Copyright (C) 1998, 1999, 2001, 2002 Milan Zamazal
 
 ;; Author: Milan Zamazal <pdm@zamazal.org>
-;; Version: $Id: py2texi.el,v 1.8 2003/07/16 03:44:48 fdrake Exp $
+;; Version: $Id: py2texi.el,v 1.9 2003/09/28 03:10:09 fdrake Exp $
 ;; Keywords: python
 
 ;; COPYRIGHT NOTICE
@@ -569,9 +569,13 @@ Do not include .ind files."
 			  (string-match "\\.ind\\.tex$" filename)))
       (setq dirs py2texi-dirs)
       (while (and (not includefile) dirs)
-	(setq includefile (concat path (car dirs) filename))
+	(setq includefile
+              (concat (file-name-as-directory (car dirs)) filename))
+        (if (not (file-name-absolute-p includefile))
+            (setq includefile
+                  (concat (file-name-as-directory path) includefile)))
 	(unless (file-exists-p includefile)
-	  (setq includefile nil)
+          (setq includefile nil)
 	  (setq dirs (cdr dirs))))
       (if includefile
 	  (save-restriction
